pub fn fsync(file: File) -> Result<DiskIoFuture>Expand description
Fsync a file, flushing all data and metadata to disk.
Panics
Panics if called outside the ringline async executor.
pub fn fsync(file: File) -> Result<DiskIoFuture>Fsync a file, flushing all data and metadata to disk.
Panics if called outside the ringline async executor.