ConnStream

Struct ConnStream 

pub struct ConnStream { /* private fields */ }
Wraps a ConnCtx and implements futures_io::{AsyncRead, AsyncWrite, AsyncBufRead}. Wraps a ConnCtx and implements AsyncRead, AsyncWrite, and AsyncBufRead.

Created via ConnStream::new. The inner ConnCtx is still accessible via conn_ctx for operations that have no trait equivalent (e.g. connect, shutdown_write).

Copy profile

Trait methodCopies (recv)Mechanism
AsyncRead::poll_read1accumulator → caller buf
AsyncBufRead::poll_fill_buf0refcounted Bytes slice
AsyncWrite::poll_write1caller buf → send pool

Implementations

Source

impl ConnStream

pub fn new(ctx: ConnCtx) -> Self

Wrap a ConnCtx in a streaming adapter.

pub fn conn_ctx(&self) -> ConnCtx

Borrow the inner ConnCtx.

Useful for operations without a trait equivalent, such as ConnCtx::connect or ConnCtx::peer_addr.