Async filesystem I/O via io_uring.
Provides buffered file read/write and metadata operations (stat, rename, unlink, mkdir) using native io_uring opcodes — no blocking syscalls.
Structs
- File
- Opaque handle to an opened file.
- FsConfig
- Configuration for async filesystem I/O.
- Metadata
- File metadata returned by
stat(). - Open
Flags - Flags for
open(). - Open
Future - Future that resolves to a
Filehandle when the open completes. - Read
Future - Future returned by
read_into(). - Stat
Future - Future that resolves to
Metadatawhen the stat completes. - Write
Future - Future returned by
write_from().
Functions
- close
- Close a file handle.
- create
- Create a file (shorthand for open with CREATE | WRITE | TRUNCATE, mode 0o644).
- fsync
- Fsync a file, flushing all data and metadata to disk.
- mkdir
- Create a directory.
- open
- Open a file asynchronously via io_uring.
- read⚠
- Read from a file at the given offset.
- read_
into - Read from a file at the given offset into a
BytesMut. - remove
- Remove a file (unlink).
- rename
- Rename a file.
- stat
- Get file metadata (stat) for a path.
- write⚠
- Write to a file at the given offset.
- write_
from - Write to a file at the given offset from a
BytesMut.